# test_mh.py

import unittest

from mh import eg

class TestMh(unittest.TestCase):
    def test_1(self):
        print ('in test 1')
        print (dir(eg))
        r = eg.test()
        print (r)

        x = eg.Mh()
        x.runMh()


if __name__ == '__main__':
    unittest.main()



# eg.py
'''
eg code
'''

EG_VAR='ABCD'

def testFunction():
    ''' returns a test string '''
    return 'OK'

class Mh (object):
    ''' Eg class '''

    def runMh(self):
        ''' Eg class function '''
        print ('OK RUN')
        return 100





# eg.py
'''
eg code
'''

EG_VAR='abcd'

def test():
    ''' returns a test string '''
    return 'ok'

class Mh (object):
    ''' eg class doc string '''
    def runMh(self):
        ''' doc string for member function '''
        print ('ok run')
        return 10

